#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-retrie-plugin-2.3.0.0-DQh0PUqINy630bgCSynkDZ
key:                  hls-retrie-plugin-2.3.0.0-DQh0PUqINy630bgCSynkDZ
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  afaba1719138ce6945144f2164fa1c09
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.3.0.0-DQh0PUqINy630bgCSynkDZ
depends:
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-JQjr8PVpkEB4amK6gdUMOF ghc-9.6.6
    ghcide-2.3.0.0-2s8rQV9irz21pyc5cIsIV0
    hashable-1.4.7.0-Ws19qMM2f99bApawlWBTg
    hls-plugin-api-2.3.0.0-JWlMOnERUdN8af70lHp5qp
    hls-refactor-plugin-2.3.0.0-4jTWipC9q9aAyyGgrVLoOO
    lens-5.3.5-KA5gcUGZYMJ4Yj2DW4uyDf
    lsp-2.2.0.0-AApQc3pMEos5GLRJ0i2B8c
    lsp-types-2.0.2.0-4NXabkuUeFJ9jCQLmB6g4 mtl-2.3.1
    retrie-1.2.3-11Eeu0dXPMwEmeKiFHBUo3
    safe-exceptions-0.1.7.4-KsLBtnEzfQ1Kg6OJ9Y9PUU stm-2.5.1.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

